LightstreamerClientExt extension

on

Properties

connectionDetails → ConnectionDetails

Available on LightstreamerClient, provided by the LightstreamerClientExt extension

Data object that contains the details needed to open a connection to a Lightstreamer Server.
no setter
connectionOptions → ConnectionOptions

Available on LightstreamerClient, provided by the LightstreamerClientExt extension

Data object that contains options and policies for the connection to the server.
no setter

Methods

addListener(ClientListener listener) → void

Available on LightstreamerClient, provided by the LightstreamerClientExt extension

Adds a listener that will receive events from the LightstreamerClient instance.
connect() → void

Available on LightstreamerClient, provided by the LightstreamerClientExt extension

Operation method that requests to open a Session against the configured Lightstreamer Server.
disconnect() → void

Available on LightstreamerClient, provided by the LightstreamerClientExt extension

Operation method that requests to close the Session opened against the configured Lightstreamer Server (if any).
findMpnSubscription(String subscriptionId) → MpnSubscription?

Available on LightstreamerClient, provided by the LightstreamerClientExt extension

getListeners() → List<ClientListener>

Available on LightstreamerClient, provided by the LightstreamerClientExt extension

Returns a list containing the ClientListener instances that were added to this client.
getMpnSubscriptions(String? filter) → List<MpnSubscription>

Available on LightstreamerClient, provided by the LightstreamerClientExt extension

Inquiry method that returns a collection of the existing MPN subscription with a specified status.
getStatus() → String

Available on LightstreamerClient, provided by the LightstreamerClientExt extension

Inquiry method that gets the current client status and transport (when applicable).
getSubscriptions() → List<Subscription>

Available on LightstreamerClient, provided by the LightstreamerClientExt extension

Inquiry method that returns a list containing all the Subscription instances that are currently "active" on this LightstreamerClient.
registerForMpn(MpnDevice device) → void

Available on LightstreamerClient, provided by the LightstreamerClientExt extension

Operation method that registers the MPN device on the server's MPN Module.
removeListener(ClientListener listener) → void

Available on LightstreamerClient, provided by the LightstreamerClientExt extension

Removes a listener from the LightstreamerClient instance so that it will not receive events anymore.
sendMessage(String message, [String? sequence, int? delayTimeout, ClientMessageListener? listener, bool? enqueueWhileDisconnected]) → void

Available on LightstreamerClient, provided by the LightstreamerClientExt extension

Operation method that sends a message to the Server.
subscribe(Subscription sub) → void

Available on LightstreamerClient, provided by the LightstreamerClientExt extension

Operation method that adds a Subscription to the list of "active" Subscriptions. The Subscription cannot already be in the "active" state.
subscribeMpn(MpnSubscription subscription, bool coalescing) → void

Available on LightstreamerClient, provided by the LightstreamerClientExt extension

Operation method that subscribes an MpnSubscription on server's MPN Module.
unsubscribe(Subscription sub) → void

Available on LightstreamerClient, provided by the LightstreamerClientExt extension

Operation method that removes a Subscription that is currently in the "active" state.
unsubscribeMpn(MpnSubscription sub) → void

Available on LightstreamerClient, provided by the LightstreamerClientExt extension

Operation method that unsubscribes an MpnSubscription from the server's MPN Module.
unsubscribeMpnSubscriptions(String? filter) → void

Available on LightstreamerClient, provided by the LightstreamerClientExt extension

Operation method that unsubscribes all the MPN subscriptions with a specified status from the server's MPN Module.